darkhistory.electrons.ics.ics_cooling.get_ics_cooling_tf — DarkHistory documentation

# darkhistory.electrons.ics.ics_cooling.get_ics_cooling_tf

`darkhistory.electrons.ics.ics_cooling.` `get_ics_cooling_tf`(raw_thomson_tf, raw_rel_tf, raw_engloss_tf, eleceng, photeng, rs, fast=True)

  Transfer function for complete electron cooling through ICS.

  Parameters: | raw_thomson_tf : TransFuncAtRedshift Raw Thomson ICS scattered photon spectrum transfer function. raw_rel_tf : TransFuncAtRedshift Raw relativistic ICS scattered photon spectrum transfer function. raw_engloss_tf : TransFuncAtRedshift Raw Thomson ICS scattered electron net energy loss spectrum transfer function. eleceng : ndarray The electron kinetic energy abscissa. photeng : ndarray The photon energy abscissa. rs : float The redshift (1+z). fast : bool, optional If True, uses optimized code (with very little checks)
  Returns: | tuple of TransFuncAtRedshift Transfer functions for photons and low energy electrons.

  Notes

  The raw transfer functions should be generated when the code package is first installed. The transfer function corresponds to the fully resolved photon spectrum after scattering by one electron.

#### Previous topic

darkhistory.electrons.ics.ics_cooling

#### Next topic

darkhistory.electrons.ics.ics_cooling.get_ics_cooling_tf_fast

### This Page

Show Source